@@ -8,23 +8,19 @@
 class Arbiter
 {
     size_t d_index;
-    Alternatives const &d_alternatives;
-        
+    Alternatives &d_alternatives;
+            
     public:
-        Arbiter(Alternatives const &alternatives);
+        Arbiter(Alternatives &alternatives);
 
         void select();
-        inline bool decided() const;
+        bool decided() const;
 
     private:
         void showAlternatives() const;
-        size_t show(size_t begin, char first, char last) const;
+        size_t show(size_t begin, char first, char last, 
+                                                size_t separateAt) const;
         void setIndex();
 };
 
-bool Arbiter::decided() const
-{
-    return d_index != d_alternatives.size();
-}
-
 #endif
